expand_gpu_processes

Function expand_gpu_processes 

pub(crate) fn expand_gpu_processes(
    process_nodes: &HashMap<u32, HashSet<u32>>,
    cgroups: &CgroupReader,
) -> HashMap<u32, u32>
Expand NVML processes to peer processes in the same exact cgroup.

NVML remains the source of GPU usage and NUMA locality. Cgroups are used only to discover the other processes that belong to the same workload.